/*  GSMP - General Sound Manipulation Program
 *  Copyright (C) 2000-2002 Kristian Peters, Ren Rebe and Valentin Ziegler
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/* Short Description:
 *   The Button-bar.
 */

#include "plugins-gtk/ButtonBar.hh"

using namespace Gtk;
using namespace GSMP;
using namespace GSML;
using namespace Gtk::Toolbar_Helpers;

ButtonBar::ButtonBar(View* i_view)
  : Toolbar (GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH),
    zoom_in (i_view, "View>zoom in"),
    zoom_out (i_view, "View>zoom out"),
    zoom_data (i_view, "View>zoom>all data"),
    zoom_sel (i_view, "View>zoom>selection"),
    play (i_view, "IO>Start IO"),
    loop (i_view, "IO>Start IO"), /* TODO: Replace by some kind of Toggle Button and add loop mode! */
    stop (i_view, "IO>Stop IO")
{
  m_view = i_view;
  m_project = m_view -> GetProject ();

  set_border_width (0);

  /* lets define pixmaps for the buttons */
  zoom_in.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/zoom_in.xpm") );
  zoom_in.set_relief(GTK_RELIEF_NONE);
  zoom_out.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/zoom_out.xpm") );
  zoom_out.set_relief(GTK_RELIEF_NONE);
  zoom_data.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/zoom_data.xpm") );
  zoom_data.set_relief(GTK_RELIEF_NONE);
  zoom_sel.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/zoom_sel.xpm") );
  zoom_sel.set_relief(GTK_RELIEF_NONE);
  play.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/play.xpm") );
  play.set_relief(GTK_RELIEF_NONE);
  loop.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/loop.xpm") );
  loop.set_relief(GTK_RELIEF_NONE);
  stop.SetPixmap (GSMP_PATH_DATA + string ("/pixmaps/stop.xpm") );
  stop.set_relief(GTK_RELIEF_NONE);
  
  /* set tooltips for the buttons */
  tt_zoom_in.set_tip (zoom_in, "zoom in");
  tt_zoom_out.set_tip (zoom_out, "zoom out");
  tt_zoom_data.set_tip (zoom_data, "zoom all data");
  tt_zoom_sel.set_tip (zoom_sel, "zoom to selection");
  tt_play.set_tip (play, "start I/O");
  tt_loop.set_tip (loop, "activate loop (not implemented)");
  tt_stop.set_tip (stop, "stop I/O");

  /* Add Eventboxes */
  eb_zoom_in.add (zoom_in);
  eb_zoom_out.add (zoom_out);
  eb_zoom_data.add (zoom_data);
  eb_zoom_sel.add (zoom_sel);
  eb_play.add (play);
  eb_loop.add (loop);
  eb_stop.add (stop);

  /* lets put the gtkmm-components (widgets) into the appropiate container */
  tools().push_back (eb_zoom_in);
  tools().push_back (eb_zoom_out);
  tools().push_back (eb_zoom_data);
  tools().push_back (eb_zoom_sel);
  tools().push_back (Space () );
  tools().push_back (eb_play);
  tools().push_back (eb_loop);
  tools().push_back (eb_stop);

  /* show all components */
  show_all ();
}
  
